@@ -14,6 +14,66 @@ from screeninfo import get_monitors
 from kivy.properties import StringProperty, NumericProperty, BooleanProperty, ListProperty
 
 
+def Help():
+    print('''builder_string: str = '', app_name: str = '', list_of_files: list = None,
+                 screen_size=None, min_x: int = 0.1, min_y: int = 0.1, center: bool = True,
+                 run_at_build: bool = False, sun_icon: str = 'white-balance-sunny',
+                 moon_icon: str = 'weather-night', main_color: str = 'Blue''')
+
+def Spec(name: str, filename: str, icon: str, path: str = os.getcwd()):
+
+    path = path.replace("\\", r"\\")
+
+    print(fr"""
+from kivy_deps import sdl2, glew
+
+# -*- mode: python ; coding: utf-8 -*-
+
+
+block_cipher = None
+
+a = Analysis(['{filename}'],
+             pathex=[{path}],
+             binaries=[],
+             datas=[],
+             hiddenimports=[],
+             hookspath=[],
+             hooksconfig={{}},
+             runtime_hooks=[],
+             excludes=[],
+             win_no_prefer_redirects=False,
+             win_private_assemblies=False,
+             cipher=block_cipher,
+             noarchive=False)
+
+pyz = PYZ(a.pure, a.zipped_data,
+             cipher=block_cipher)
+
+exe = EXE(pyz,
+          a.scripts,
+          [],
+          exclude_binaries=True,
+          name='{name}',
+          debug=False,
+          bootloader_ignore_signals=False,
+          strip=False,
+          upx=True,
+          console=False,
+          disable_windowed_traceback=False,
+          target_arch=None,
+          codesign_identity=None,
+          entitlements_file=None, icon='{icon}')
+
+coll = COLLECT(exe, Tree('{path}'),
+               a.binaries,
+               a.zipfiles,
+               a.datas,
+               *[Tree(p) for p in (sdl2.dep_bins + glew.dep_bins)],
+               strip=False,
+               upx=True,
+               upx_exclude=[],
+               name='{name}')""")
+
 class Kivy4(MDApp):
 
     def __init__(self, builder_string: str = '', app_name: str = '', list_of_files: list = None,
@@ -45,14 +105,13 @@ class Kivy4(MDApp):
 
         self.run_at_build = run_at_build
 
-        self.build()
         self.run()
 
     def build(self):
         self.use_kivy_settings = False
         self.settings_cls = ContentPanel
         self.title = self.app_name
-        Window.bind(on_request_close=self.on_request_close)
+        Window.bind(on_request_close=lambda x: self.on_request_close())
 
         if self.run_at_build:
             self.Build()
@@ -154,6 +213,13 @@ class Kivy4(MDApp):
             value = darkdetect.theme()
 
         self.setFile(filename, value)
+
+        if value == 'Dark':
+            self.dark_mode_icon = self.moon_icon
+
+        else:
+            self.dark_mode_icon = self.sun_icon
+
         self.theme_cls.theme_style = value
 
     def reverseDarkMode(self, filename: str = 'dark mode.txt'):
